==> sigaddons-7.0.21.12.14.tar.gz: sigaddons-7.0.21.12.14/sigaddons/recebimento/__openerp__.py <==
# -*- encoding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2013 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz@siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2013, Creative Commons
# Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
#
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

{
    'name': 'Recebimento de mercadorias',
    'description': """
Recebimento
===========
O recebimento de mercadorias e responsavel por assegurar que o vendedor entregou o produto certo, em boas condicoes, nas quantidades certas e no momento certo.
Todos os itens/volumes sao conferidos e caso haja qualquer inconsistencia, ficara registrado em sistema.
    """,
    'category': 'Estoque',
    'version': '7.0.21.12.14',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['fiscal'],
    'data': [
        'security/recebimento_security.xml',
        'security/ir.model.access.csv',
        'os/security/os_security.xml',
        'os/security/ir.model.access.csv',

        'data/os_tipo.xml',  # Tipo da ordem de servico - 'REC'/Recebimento

        'os/views/os_view.xml',  # Ordem de servico
        'os/views/action.xml',


        'inherit/fiscal/nf_capa_view.xml',
        'inherit/os/os_view.xml',  # Ordem de servico de recebimento
        'inherit/estoque/parametro_view.xml',  # Parametros de recebimento
        'inherit/os/historico_os_view.xml',  # Historico das acoes

        'views/divergencia_nf_view.xml',  # Divergencias (notas fiscais com divergencia)
        'views/recebimento_itens_view.xml',  # Itens de recebimento
        'views/divergencia_itens_view.xml',  # Itens de divergencia

        'views/action.xml',
        'views/menu.xml'
    ],
    'license': 'Other proprietary',
    "application": True,
    'installable': True,
    'active': False
}

==> sigaddons-7.0.2310.2.tar.gz: sigaddons-7.0.2310.2/sigaddons/recebimento/__openerp__.py <==
# -*- encoding: utf-8 -*-
################################################################################
#
# Copyright (C) 2009-2013 All Rights Reserved. Luiz Fernando Maciel Franca
#              www.siginformatica.com.br <luiz@siginformatica.com.br>
#                                -------
#
# Copyleft (CC) 2013, Creative Commons
# Autor - Pierre Geraldo Moura Barbosa <barbosa.pierre[at]gmail.com>
#
# Atribuicao-Nao Comercial-Compartilhada Igual 3 Nao Adaptada (CC BY-NC-SA 3.0)
# http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
#
################################################################################

{
    'name': 'Recebimento de mercadorias',
    'description': """
Recebimento
===========
O recebimento de mercadorias e responsavel por assegurar que o vendedor entregou o produto certo, em boas condicoes, nas quantidades certas e no momento certo.
Todos os itens/volumes sao conferidos e caso haja qualquer inconsistencia, ficara registrado em sistema.
    """,
    'category': 'Estoque',
    'version': '7.0.2310.2',
    'author': 'Sig Informatica Ltda',
    'website': 'http://www.siginformatica.com.br',
    'depends': ['fiscal'],
    'data': [
        'security/recebimento_security.xml',
        'security/ir.model.access.csv',
        'os/security/os_security.xml',
        'os/security/ir.model.access.csv',

        'data/os_tipo.xml',  # Tipo da ordem de servico - 'REC'/Recebimento

        'os/views/os_view.xml',  # Ordem de servico
        'os/views/action.xml',


        'inherit/fiscal/nf_capa_view.xml',
        'inherit/os/os_view.xml',  # Ordem de servico de recebimento
        'inherit/estoque/parametro_view.xml',  # Parametros de recebimento
        'inherit/os/historico_os_view.xml',  # Historico das acoes

        'views/divergencia_nf_view.xml',  # Divergencias (notas fiscais com divergencia)
        'views/recebimento_itens_view.xml',  # Itens de recebimento
        'views/divergencia_itens_view.xml',  # Itens de divergencia

        'views/action.xml',
        'views/menu.xml'
    ],
    'license': 'Other proprietary',
    "application": True,
    'installable': True,
    'active': False
}
